==> haskell-text-format-0.3.2-31-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-format.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 text-format
version:              0.3.2
visibility:           public
id:                   text-format-0.3.2-3JHb3XrjFODCvQqbYUHKe6
key:                  text-format-0.3.2-3JHb3XrjFODCvQqbYUHKe6
license:              BSD-3-Clause
maintainer:           Bryan O'\''Sullivan <bos@serpentine.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/bos/text-format
synopsis:             Text formatting
description:
    A text formatting library optimized for both ease of use and high
    performance.

category:             Text
abi:                  ec7514a03c1eecf938e0de2bc96ea0aa
exposed:              True
exposed-modules:
    Data.Text.Buildable Data.Text.Format Data.Text.Format.Params
    Data.Text.Format.Types Data.Text.Format.Types.Internal

hidden-modules:       Data.Text.Format.Functions Data.Text.Format.Int
import-dirs:          /usr/lib/ghc-8.10.1/site-local/text-format-0.3.2
library-dirs:         /usr/lib/ghc-8.10.1/site-local/text-format-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/text-format-0.3.2
hs-libraries:         HStext-format-0.3.2-3JHb3XrjFODCvQqbYUHKe6
depends:
    array-0.5.4.0 base-4.14.0.0
    double-conversion-2.0.2.0-L8AeOG7aMKc7HgQ5tW5Fe8 ghc-prim-0.6.1
    integer-gmp-1.0.3.0 old-locale-1.0.0.7-He1fhgasqBf2zFT9zlaLle
    text-1.2.3.2 time-1.9.3 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-text-format/html/text-format.haddock
haddock-html:         /usr/share/doc/haskell-text-format/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-format-0.3.2-32-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-format.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 text-format
version:              0.3.2
visibility:           public
id:                   text-format-0.3.2-BkOkyvMMBWS5IoeAR0j0J9
key:                  text-format-0.3.2-BkOkyvMMBWS5IoeAR0j0J9
license:              BSD-3-Clause
maintainer:           Bryan O'\''Sullivan <bos@serpentine.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/bos/text-format
synopsis:             Text formatting
description:
    A text formatting library optimized for both ease of use and high
    performance.

category:             Text
abi:                  cc77ff2c8f4885dc6a5573dfd540343a
exposed:              True
exposed-modules:
    Data.Text.Buildable Data.Text.Format Data.Text.Format.Params
    Data.Text.Format.Types Data.Text.Format.Types.Internal

hidden-modules:       Data.Text.Format.Functions Data.Text.Format.Int
import-dirs:          /usr/lib/ghc-8.10.1/site-local/text-format-0.3.2
library-dirs:         /usr/lib/ghc-8.10.1/site-local/text-format-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/text-format-0.3.2
hs-libraries:         HStext-format-0.3.2-BkOkyvMMBWS5IoeAR0j0J9
depends:
    array-0.5.4.0 base-4.14.0.0
    double-conversion-2.0.2.0-GfGiX5CMWr47nCqwmAPnuS ghc-prim-0.6.1
    integer-gmp-1.0.3.0 old-locale-1.0.0.7-He1fhgasqBf2zFT9zlaLle
    text-1.2.3.2 time-1.9.3 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-text-format/html/text-format.haddock
haddock-html:         /usr/share/doc/haskell-text-format/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
